@@ -1,6 +1,5 @@
 #!/bin/bash
-
-mversion=3.0
+mversion=4.0
 TTSENGINE=verbio
 
 echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
@@ -8,12 +7,21 @@ echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
 # Copy files
 
 perm_dir=775
-perm_files=664
+perm_files=644
 perm_exec=775
 
 src=.
 dst=
 
+#part1
+echo "Creating directories..."
+mkdir -p $dst/usr/bin
+
+echo "Installing binaries..."
+install -m $perm_dir $src/bin/verbiot2f $dst/usr/bin
+
+
+#part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
 echo $n "Enter apache web root directory[$wwwdirselect]: $c"
@@ -26,12 +34,8 @@ echo "Selected www dir : $wwwdirselect"
 mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE
 install -m $perm_files $src/www/* $dst/$wwwdirselect/tts/$TTSENGINE
 
-echo "Creating directories..."
-mkdir -p $dst/usr/bin
-
-echo "Installing binaries..."
-install -m $perm_dir $src/bin/verbiot2f $dst/usr/bin
+mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE/html5media
+install -m $perm_files $src/html5media/* $dst/$wwwdirselect/tts/$TTSENGINE/html5media/
 
 
 echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"
-
